@@ -23,31 +23,30 @@ class ComposedLink(TerminatingLink):
 
         self.links[-1](rath)  # last one gets only rath
 
-    async def aconnect(self):
-        await self.first_link.aconnect()
+    async def __aenter__(self):
+        await self.first_link.__aenter__()
 
-    async def adisconnect(self):
-        await self.first_link.adisconnect()
+    async def __aexit__(self, *args, **kwargs):
+        await self.first_link.__aexit__(*args, **kwargs)
 
-    def connect(self):
-        self.first_link.connect()
+    def __enter__(self):
+        self.first_link.__enter__()
 
-    def disconnect(self):
-        self.first_link.disconnect()
+    def __exit__(self, *args, **kwargs):
+        self.first_link.__exit__(*args, **kwargs)
 
-    async def aquery(self, operation: Operation):
+    async def aquery(self, operation: Operation, **kwargs):
         return await self.first_link.aquery(operation)
 
-    async def asubscribe(self, operation: Operation):
+    async def asubscribe(self, operation: Operation, **kwargs):
         async for result in self.first_link.asubscribe(operation):
             yield result
 
-    def query(self, operation: Operation):
-        return self.first_link.query(operation)
+    def query(self, operation: Operation, **kwargs):
+        return self.first_link.query(operation, **kwargs)
 
-    def subscribe(self, operation: Operation):
-        for result in self.first_link.subscribe(operation):
-            yield result
+    def subscribe(self, operation: Operation, **kwargs):
+        return self.first_link.subscribe(operation, **kwargs)
 
 
 def compose(*links: List[Link]) -> ComposedLink:
