@@ -1,4 +1,5 @@
 import asyncio
+from koil.decorators import koilable
 from rath.links.base import TerminatingLink
 from typing import (
     AsyncIterator,
@@ -15,6 +16,7 @@ from rath.operation import GraphQLResult, opify
 from contextvars import ContextVar
 
 
+@koilable(add_connectors=True)
 class Rath:
     def __init__(
         self,
@@ -34,10 +36,6 @@ class Rath:
         """
         self.link = link
         self.autoconnect = autoconnect
-        self.link(self)
-
-        if register:
-            set_current_rath(self)
 
     async def aexecute(
         self,
@@ -95,35 +93,9 @@ class Rath:
             yield res
 
     async def __aenter__(self):
+        self.link(self)
         await self.link.__aenter__()
         return self
 
     async def __aexit__(self, exc_type, exc_val, exc_tb):
         await self.link.__aexit__(exc_type, exc_val, exc_tb)
-
-    def __enter__(self):
-        self.link.__enter__()
-        return self
-
-    def __exit__(self, exc_type, exc_val, exc_tb):
-        self.link.__exit__(exc_type, exc_val, exc_tb)
-
-    def connect(self):
-        return self.__enter__()
-
-    def disconnect(self):
-        return self.__exit__(None, None, None)
-
-
-CURRENT_RATH = None
-
-
-def get_current_rath(**kwargs):
-    global CURRENT_RATH
-    assert CURRENT_RATH is not None, "No current rath set"
-    return CURRENT_RATH
-
-
-def set_current_rath(rath):
-    global CURRENT_RATH
-    CURRENT_RATH = rath
